/**
 * Open SUIT - Simple User Interface Toolkit
 * 
 * Copyright (c) 2009 EBM Websourcing, http://www.ebmwebsourcing.com/
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
package org.ow2.opensuit.samples.livetour.uibeans;

import java.io.Serializable;

import org.ow2.opensuit.core.validation.LocalizedValidationError;
import org.ow2.opensuit.core.validation.ValidationError;
import org.ow2.opensuit.core.validation.ValidationErrors;

public class FormValidationBean implements Serializable {
	private static final long serialVersionUID = 1L;

	private String text1;
	private String text2;
	private String text3;
	private String text4;
	private String text5;
	private String text6;

	public void reset() {
		text1 = null;
		text2 = null;
		text3 = null;
		text4 = null;
		text5 = null;
		text6 = null;
	}

	public String getText1() {
		return text1;
	}

	public void setText1(String text1) {
		this.text1 = text1;
	}

	public String getText2() {
		return text2;
	}

	public void setText2(String text2) {
		this.text2 = text2;
	}

	public String getText3() {
		return text3;
	}

	public void setText3(String text3) {
		this.text3 = text3;
	}

	public String getText4() {
		return text4;
	}

	public void setText4(String text4) {
		this.text4 = text4;
	}

	public String getText5() {
		return text5;
	}

	public void setText5(String text5) {
		this.text5 = text5;
	}

	public String getText6() {
		return text6;
	}

	public void setText6(String text6) {
		this.text6 = text6;
	}

	/**
	 * Custom validation method for one single field
	 * <p>
	 * Throws a single ValidationError
	 */
	public void checkPalindrome(String text) throws ValidationError {
		// --- checks value is a palindrome
		int l = text.length();
		int mid = l / 2;
		for (int i = 0; i < mid; i++) {
			if (text.charAt(i) != text.charAt(l - 1 - i))
				throw new LocalizedValidationError("validation.palindrome");
		}
	}

	/**
	 * Custom validation method for the entire form
	 * <p>
	 * Throws a ValidationErrors, that may contain several error descriptions
	 */
	public void validateForm() throws ValidationErrors {
		ValidationErrors errors = new ValidationErrors();

		// --- 1: cross fields validation: text2 must be a substring of text1
		if (text1 != null && text1.length() > 0 && text3 != null
				&& text3.length() > 0) {
			if (text1.indexOf(text3) < 0) {
				// --- add an error on text3 field
				errors.addItemError("form4.text3",
						new LocalizedValidationError("validation.substring",
								new Object[] { text1 }));
			}
		}

		// --- 2: global form validation: summed texts length must be > 50
		int totalLength = 0;
		totalLength += text1 == null ? 0 : text1.length();
		totalLength += text2 == null ? 0 : text2.length();
		totalLength += text3 == null ? 0 : text3.length();
		totalLength += text4 == null ? 0 : text4.length();
		totalLength += text5 == null ? 0 : text5.length();
		totalLength += text6 == null ? 0 : text6.length();

		if (totalLength < 50) {
			errors.addGlobalError(new LocalizedValidationError(
					"validation.total_len"));
		}

		if (errors.hasErrors())
			throw errors;
	}

}
